==> qtimgren-0.5.0.tar.gz: qtimgren-0.5.0/qtimgren/qtimgren_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>About</name>
    <message>
        <location filename="about.ui" line="17"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="about.ui" line="49"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="about.ui" line="56"/>
        <source>(pyimgren version: 0.0.0)</source>
        <translation>(pyimgren version : 0.0.0)</translation>
    </message>
    <message>
        <location filename="about.ui" line="63"/>
        <source>Python version:</source>
        <translation>Version de Python :</translation>
    </message>
    <message>
        <location filename="about.ui" line="29"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="profile.ui" line="14"/>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <location filename="profile.ui" line="27"/>
        <source>&amp;Name</source>
        <translation>&amp;Nom</translation>
    </message>
    <message>
        <location filename="profile.ui" line="37"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Name of the profile&lt;/p&gt;&lt;p&gt;Will be used in the &lt;span style=&quot; font-style:italic;&quot;&gt;Profiles&lt;/span&gt; menu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nom du profil&lt;/p&gt;&lt;p&gt;Servira d&apos;entrée dans le menu &lt;span style=&quot; font-style:italic;&quot;&gt;Profils&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="profile.ui" line="62"/>
        <source>Path of the image (jpeg) files</source>
        <translation>Répertoire des fichiers image (jpeg)</translation>
    </message>
    <message>
        <location filename="profile.ui" line="69"/>
        <source>&amp;Select</source>
        <translation>&amp;Choisir</translation>
    </message>
    <message>
        <source>Image &amp;mask</source>
        <translation type="vanished">&amp;Masque des images</translation>
    </message>
    <message>
        <source>Pattern of camera images (e.g. IMG*.JPG or DSCF*.JPG)</source>
        <translation type="vanished">Modèles des noms de fichiers image (par example IMG*.JPG ou DSCF*.JPG)</translation>
    </message>
    <message>
        <location filename="profile.ui" line="50"/>
        <source>&amp;Directory</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="profile.ui" line="78"/>
        <source>New name &amp;pattern</source>
        <translation>M&amp;odèle de nouveau nom</translation>
    </message>
    <message>
        <location filename="profile.ui" line="88"/>
        <source>%Y%m%d_%H%M%S.jpg</source>
        <translation></translation>
    </message>
    <message>
        <location filename="merge.ui" line="14"/>
        <source>Folder to merge</source>
        <translation>Dossier à combiner</translation>
    </message>
    <message>
        <location filename="merge.ui" line="28"/>
        <source>&amp;Folder</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="merge.ui" line="41"/>
        <source>&amp;Change</source>
        <translation>&amp;Changer</translation>
    </message>
    <message>
        <location filename="merge.ui" line="52"/>
        <source>Delta (minutes)</source>
        <translation>Décalage (minutes)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="main_window.ui" line="132"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="141"/>
        <source>&amp;Help</source>
        <translation>&amp;?</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="148"/>
        <source>&amp;Profiles</source>
        <translation>&amp;Profils</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="161"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="166"/>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="171"/>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="176"/>
        <source>&amp;New profile</source>
        <translation>&amp;Nouveau profil</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="181"/>
        <source>&amp;Manage profiles</source>
        <translation>&amp;Gestion des profils</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="186"/>
        <source>Change &amp;Folder</source>
        <translation>Change de &amp;répertoire</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="194"/>
        <source>&amp;Merge</source>
        <translation>Com&amp;bine</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="29"/>
        <source>Display &amp;images</source>
        <translation>Affiche les &amp;images</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="52"/>
        <source>Automatic selections</source>
        <translation>Sélections automatiques</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="60"/>
        <source>Default &amp;selection</source>
        <translation>&amp;Sélection par défaut</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="67"/>
        <source>Select renamed &amp;images</source>
        <translation>Images re&amp;nommées</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="81"/>
        <source>&amp;Delta (minutes)</source>
        <translation>Décalage (minutes)</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="104"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomme</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="111"/>
        <source>&amp;Back</source>
        <translation>Noms d&apos;&amp;origine</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="199"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuration</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="14"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="app.py" line="19"/>
        <location filename="app.py" line="61"/>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <location filename="app.py" line="22"/>
        <source>French</source>
        <translation>Français</translation>
    </message>
</context>
<context>
    <name>merge</name>
    <message>
        <location filename="merge_dialog.py" line="36"/>
        <source>New folder</source>
        <translation>Nouveau dossier</translation>
    </message>
</context>
<context>
    <name>profile</name>
    <message>
        <location filename="profile.py" line="71"/>
        <source>&quot;{}&quot; is already used</source>
        <translation>&quot;{}&quot; est déjà utilisé</translation>
    </message>
    <message>
        <location filename="profile.py" line="75"/>
        <source>Name cannot be empty</source>
        <translation>Le nom ne peut pas être vide</translation>
    </message>
    <message>
        <source>&quot;{}&quot; is not a valid image pattern</source>
        <translation type="vanished">&quot;{}&quot; n&apos;est pas un modèle valide</translation>
    </message>
    <message>
        <location filename="profile.py" line="72"/>
        <location filename="profile.py" line="76"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="profile.py" line="81"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation type="vanished">Modèle</translation>
    </message>
    <message>
        <location filename="profile.py" line="89"/>
        <source>&quot;{}&quot; is not a valid date pattern</source>
        <translation>&quot;{}&quot; n&apos;est pas un modèle de date valide</translation>
    </message>
    <message>
        <location filename="profile.py" line="90"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
</context>
<context>
    <name>profile_manager</name>
    <message>
        <location filename="profile_manager.py" line="79"/>
        <source>{} already exists</source>
        <translation>{} existe déjà</translation>
    </message>
</context>
<context>
    <name>profiles</name>
    <message>
        <location filename="profiles.ui" line="14"/>
        <source>Profiles</source>
        <translation>Profils</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="36"/>
        <source>Edit the (first) selected profile</source>
        <translation>Édite le (premier) profil sélectionné</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="39"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edite</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="46"/>
        <source>Remove every selected profile</source>
        <translation>Supprime tous les profils sélectionnés</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="49"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprime</translation>
    </message>
    <message>
        <location filename="profile.py" line="80"/>
        <source>&quot;{}&quot; is not a valid folder</source>
        <translation>&quot;{}&quot; n&apos;est pas un dossier valide</translation>
    </message>
    <message>
        <location filename="profiles.py" line="42"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="profiles.py" line="43"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation type="vanished">Modèle</translation>
    </message>
    <message>
        <location filename="profiles.py" line="45"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
    <message>
        <location filename="profiles.py" line="127"/>
        <source>&quot;{1}&quot; is a duplicate&lt;br/&gt;already present at row {0}</source>
        <translation>{1} est déjà présent&lt;br/&gt;ligne {0}</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="settings.ui" line="14"/>
        <source>Settings</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="settings.ui" line="31"/>
        <source>&amp;Use cache</source>
        <translation>&amp;Utilisation du cache</translation>
    </message>
    <message>
        <source>If unchecked no image caching will occur. It will save memory at the price of slow and not smocth scrolling</source>
        <translation type="vanished">Si non coché, les vignettes ne seront pas mise en cache. Cela économise de la mémoire au prix d&apos;un défilement long et saccadé</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>If unchecked no image caching will occur. It will save memory at the price of slow and not smooth scrolling</source>
        <translation>Si non coché, les vignettes ne seront pas mise en cache. Cela économise de la mémoire au prix d&apos;un défilement long et saccadé</translation>
    </message>
    <message>
        <location filename="settings.ui" line="51"/>
        <source>Cache &amp;size</source>
        <translation>&amp;Taille du cache</translation>
    </message>
    <message>
        <location filename="settings.ui" line="61"/>
        <source>Maximum number of images that can be cached or &quot;unlimited&apos;. It should be unlimited if you have enough memory, but can allow qtimgren to run on smaller systems.</source>
        <translation>Nombre maximum d&apos;images à mettre en cache ou &quot;illimité&quot;. Utiliser de préférnce illimité si vous avez suffisamment de mémoire, mais des valeurs faibles peuvent permettre à qtimgren de fonctionner sur des systèmes limités.</translation>
    </message>
    <message>
        <location filename="settings.ui" line="64"/>
        <source>Unlimited</source>
        <translation>Illimité</translation>
    </message>
    <message>
        <location filename="settings.ui" line="83"/>
        <source>Choose the language for the interface</source>
        <translation>Choix de la langue utilisée dans l&apos;application</translation>
    </message>
    <message>
        <location filename="settings.ui" line="86"/>
        <source>&amp;Language</source>
        <translation>&amp;Langue</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Anglais</translation>
    </message>
</context>
<context>
    <name>view</name>
    <message>
        <location filename="abstract_view.py" line="61"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="abstract_view.py" line="61"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="abstract_view.py" line="62"/>
        <source>Original</source>
        <translation>Nom d&apos;origine</translation>
    </message>
    <message>
        <location filename="abstract_view.py" line="63"/>
        <source>New name</source>
        <translation>Nouveau nom</translation>
    </message>
</context>
</TS>

==> qtimgren-0.5.2.tar.gz: qtimgren-0.5.2/qtimgren/qtimgren_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>About</name>
    <message>
        <location filename="about.ui" line="17"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="about.ui" line="49"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="about.ui" line="56"/>
        <source>(pyimgren version: 0.0.0)</source>
        <translation>(pyimgren version : 0.0.0)</translation>
    </message>
    <message>
        <location filename="about.ui" line="63"/>
        <source>Python version:</source>
        <translation>Version de Python :</translation>
    </message>
    <message>
        <location filename="about.ui" line="29"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="profile.ui" line="14"/>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <location filename="profile.ui" line="25"/>
        <source>&amp;Name</source>
        <translation>&amp;Nom</translation>
    </message>
    <message>
        <location filename="profile.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Name of the profile&lt;/p&gt;&lt;p&gt;Will be used in the &lt;span style=&quot; font-style:italic;&quot;&gt;Profiles&lt;/span&gt; menu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nom du profil&lt;/p&gt;&lt;p&gt;Servira d&apos;entrée dans le menu &lt;span style=&quot; font-style:italic;&quot;&gt;Profils&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="profile.ui" line="60"/>
        <source>Path of the image (jpeg) files</source>
        <translation>Répertoire des fichiers image (jpeg)</translation>
    </message>
    <message>
        <location filename="profile.ui" line="67"/>
        <source>&amp;Select</source>
        <translation>&amp;Choisir</translation>
    </message>
    <message>
        <location filename="profile.ui" line="93"/>
        <source>Use disk &amp;cache</source>
        <translation>Utilise un &amp;cache sur disque</translation>
    </message>
    <message>
        <source>Image &amp;mask</source>
        <translation type="vanished">&amp;Masque des images</translation>
    </message>
    <message>
        <source>Pattern of camera images (e.g. IMG*.JPG or DSCF*.JPG)</source>
        <translation type="vanished">Modèles des noms de fichiers image (par example IMG*.JPG ou DSCF*.JPG)</translation>
    </message>
    <message>
        <location filename="profile.ui" line="48"/>
        <source>&amp;Directory</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="profile.ui" line="76"/>
        <source>New name &amp;pattern</source>
        <translation>M&amp;odèle de nouveau nom</translation>
    </message>
    <message>
        <location filename="profile.ui" line="86"/>
        <source>%Y%m%d_%H%M%S.jpg</source>
        <translation></translation>
    </message>
    <message>
        <location filename="merge.ui" line="14"/>
        <source>Folder to merge</source>
        <translation>Dossier à combiner</translation>
    </message>
    <message>
        <location filename="merge.ui" line="28"/>
        <source>&amp;Folder</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="merge.ui" line="41"/>
        <source>&amp;Change</source>
        <translation>&amp;Changer</translation>
    </message>
    <message>
        <location filename="merge.ui" line="52"/>
        <source>Delta (minutes)</source>
        <translation>Décalage (minutes)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="main_window.ui" line="132"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="141"/>
        <source>&amp;Help</source>
        <translation>&amp;?</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="148"/>
        <source>&amp;Profiles</source>
        <translation>&amp;Profils</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="160"/>
        <source>Disk &amp;cache</source>
        <translation>&amp;Cache disque</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="175"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="178"/>
        <source>Exit from the application</source>
        <translation>Quitte l&apos;application</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="183"/>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="186"/>
        <source>Version information for QtImgren</source>
        <translation>Informations sur les versions de QtImgren</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="191"/>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="194"/>
        <source>Information about the underlying Qt framework</source>
        <translation>Informations sur l&apos;environnement Qt sous jacent</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="199"/>
        <source>&amp;New profile</source>
        <translation>&amp;Nouveau profil</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="202"/>
        <source>Create a new profile</source>
        <translation>Crée un nouveau profil</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="207"/>
        <source>&amp;Manage profiles</source>
        <translation>&amp;Gestion des profils</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="210"/>
        <source>Edit or remove existing profiles</source>
        <translation>Edite ou supprime des profils existants</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="215"/>
        <source>Change &amp;Folder</source>
        <translation>Change de &amp;répertoire</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="223"/>
        <source>&amp;Merge</source>
        <translation>Com&amp;bine</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="234"/>
        <source>Configure the language and cache</source>
        <translation>Configure la langue et le cache</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="239"/>
        <source>&amp;Clean</source>
        <translation>&amp;Nettoie</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="242"/>
        <source>Remove unused entries from the cache</source>
        <translation>Supprime les entrées inutiles du cache</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="247"/>
        <source>&amp;Reset</source>
        <translation>&amp;Réinitialise</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="250"/>
        <source>Purge all entries from the cache</source>
        <translation>Vide complètement le cache</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="255"/>
        <source>&amp;Informations</source>
        <translation>&amp;Informations</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="258"/>
        <source>Cache informations</source>
        <translation>Informations sur le cache</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="29"/>
        <source>Display &amp;images</source>
        <translation>Affiche les &amp;images</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="52"/>
        <source>Automatic selections</source>
        <translation>Sélections automatiques</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="60"/>
        <source>Default &amp;selection</source>
        <translation>&amp;Sélection par défaut</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="67"/>
        <source>Select renamed &amp;images</source>
        <translation>Images re&amp;nommées</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="81"/>
        <source>&amp;Delta (minutes)</source>
        <translation>&amp;Décalage (minutes)</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="104"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomme</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="111"/>
        <source>&amp;Back</source>
        <translation>Noms d&apos;&amp;origine</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="226"/>
        <source>Merge pictures from another folder</source>
        <translation>Fusionne des images depuis un autre dossier</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="231"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuration</translation>
    </message>
    <message>
        <location filename="main_window.ui" line="14"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="app.py" line="19"/>
        <location filename="app.py" line="61"/>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <location filename="app.py" line="22"/>
        <source>French</source>
        <translation>Français</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main_window.py" line="155"/>
        <source>Cache filling: {nb_cached}/{nb_files}</source>
        <translation>Remplissage du cache : {nb_cached}/{nb_files}</translation>
    </message>
    <message>
        <location filename="main_window.py" line="158"/>
        <source> - extra: {0}</source>
        <translation> - extra : {0}</translation>
    </message>
</context>
<context>
    <name>merge</name>
    <message>
        <location filename="merge_dialog.py" line="37"/>
        <source>New folder</source>
        <translation>Nouveau dossier</translation>
    </message>
</context>
<context>
    <name>profile</name>
    <message>
        <location filename="profile.py" line="75"/>
        <source>&quot;{}&quot; is already used</source>
        <translation>&quot;{}&quot; est déjà utilisé</translation>
    </message>
    <message>
        <location filename="profile.py" line="79"/>
        <source>Name cannot be empty</source>
        <translation>Le nom ne peut pas être vide</translation>
    </message>
    <message>
        <source>&quot;{}&quot; is not a valid image pattern</source>
        <translation type="vanished">&quot;{}&quot; n&apos;est pas un modèle valide</translation>
    </message>
    <message>
        <location filename="profile.py" line="76"/>
        <location filename="profile.py" line="80"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="profile.py" line="85"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation type="vanished">Modèle</translation>
    </message>
    <message>
        <location filename="profile.py" line="93"/>
        <source>&quot;{}&quot; is not a valid date pattern</source>
        <translation>&quot;{}&quot; n&apos;est pas un modèle de date valide</translation>
    </message>
    <message>
        <location filename="profile.py" line="94"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
</context>
<context>
    <name>profile_manager</name>
    <message>
        <location filename="profile_manager.py" line="84"/>
        <source>{} already exists</source>
        <translation>{} existe déjà</translation>
    </message>
</context>
<context>
    <name>profiles</name>
    <message>
        <location filename="profiles.ui" line="14"/>
        <source>Profiles</source>
        <translation>Profils</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="36"/>
        <source>Edit the (first) selected profile</source>
        <translation>Édite le (premier) profil sélectionné</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="39"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edite</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="46"/>
        <source>Remove every selected profile</source>
        <translation>Supprime tous les profils sélectionnés</translation>
    </message>
    <message>
        <location filename="profiles.ui" line="49"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprime</translation>
    </message>
    <message>
        <location filename="profile.py" line="84"/>
        <source>&quot;{}&quot; is not a valid folder</source>
        <translation>&quot;{}&quot; n&apos;est pas un dossier valide</translation>
    </message>
    <message>
        <location filename="profiles.py" line="42"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="profiles.py" line="43"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation type="vanished">Modèle</translation>
    </message>
    <message>
        <location filename="profiles.py" line="45"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
    <message>
        <location filename="profiles.py" line="127"/>
        <source>&quot;{1}&quot; is a duplicate&lt;br/&gt;already present at row {0}</source>
        <translation>{1} est déjà présent&lt;br/&gt;ligne {0}</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="settings.ui" line="14"/>
        <source>Settings</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="settings.ui" line="31"/>
        <source>&amp;Use cache</source>
        <translation>&amp;Utilisation du cache</translation>
    </message>
    <message>
        <source>If unchecked no image caching will occur. It will save memory at the price of slow and not smocth scrolling</source>
        <translation type="vanished">Si non coché, les vignettes ne seront pas mise en cache. Cela économise de la mémoire au prix d&apos;un défilement long et saccadé</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>If unchecked no image caching will occur. It will save memory at the price of slow and not smooth scrolling</source>
        <translation>Si non coché, les vignettes ne seront pas mise en cache. Cela économise de la mémoire au prix d&apos;un défilement long et saccadé</translation>
    </message>
    <message>
        <location filename="settings.ui" line="51"/>
        <source>Cache &amp;size</source>
        <translation>&amp;Taille du cache</translation>
    </message>
    <message>
        <location filename="settings.ui" line="61"/>
        <source>Maximum number of images that can be cached or &quot;unlimited&apos;. It should be unlimited if you have enough memory, but can allow qtimgren to run on smaller systems.</source>
        <translation>Nombre maximum d&apos;images à mettre en cache ou &quot;illimité&quot;. Utiliser de préférnce illimité si vous avez suffisamment de mémoire, mais des valeurs faibles peuvent permettre à qtimgren de fonctionner sur des systèmes limités.</translation>
    </message>
    <message>
        <location filename="settings.ui" line="64"/>
        <source>Unlimited</source>
        <translation>Illimité</translation>
    </message>
    <message>
        <location filename="settings.ui" line="83"/>
        <source>Choose the language for the interface</source>
        <translation>Choix de la langue utilisée dans l&apos;application</translation>
    </message>
    <message>
        <location filename="settings.ui" line="86"/>
        <source>&amp;Language</source>
        <translation>&amp;Langue</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Anglais</translation>
    </message>
</context>
<context>
    <name>view</name>
    <message>
        <location filename="abstract_view.py" line="68"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="abstract_view.py" line="68"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="abstract_view.py" line="69"/>
        <source>Original</source>
        <translation>Nom d&apos;origine</translation>
    </message>
    <message>
        <location filename="abstract_view.py" line="70"/>
        <source>New name</source>
        <translation>Nouveau nom</translation>
    </message>
</context>
</TS>
